@@ -1,32 +1,21 @@
-/* This file is part of the KDE libraries
-    Copyright (c) 2013 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2013 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QProcess>
-#include <QFile>
-#include <QTest>
 #include <QDebug>
+#include <QFile>
+#include <QProcess>
+#include <QTest>
 
 class KCrashTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
-    void initTestCase() {
+    void initTestCase()
+    {
         // Don't bring up drkonqi
         qputenv("KDE_DEBUG", "1");
         // change to the bin dir
@@ -35,7 +24,6 @@ private Q_SLOTS:
     void testAutoRestart();
     void testAutoRestartDirectly();
     void testEmergencySave();
-
 };
 
 static const char s_logFileName[] = "kcrashtest_log";
@@ -62,7 +50,7 @@ static void startCrasher(const QByteArray &flag, const QByteArray &expectedOutpu
     QVERIFY(QFile::exists("./test_crasher"));
     processName = QStringLiteral("./test_crasher");
 #endif
-    //qDebug() << proc.args();
+    // qDebug() << proc.args();
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     env.insert(QStringLiteral("ASAN_OPTIONS"), QStringLiteral("handle_segv=0,poison_heap=0")); // Disable ASAN
     proc.setProcessEnvironment(env);
