@@ -33,7 +33,6 @@
 #endif
 
 #include <KAboutData>
-#include <kstartupinfo.h>
 
 #include <algorithm>
 #include <array>
@@ -352,7 +351,12 @@ void KCrash::setDrKonqiEnabled(bool enabled)
     }
     s_launchDrKonqi = launchDrKonqi;
     if (s_launchDrKonqi && !s_drkonqiPath) {
-        const QString exec = QStandardPaths::findExecutable(QStringLiteral("drkonqi"), libexecPaths());
+#ifdef Q_OS_WINDOWS
+        static const QString drkonqi = QStringLiteral("drkonqi.exe");
+#else
+        static const QString drkonqi = QStringLiteral("drkonqi");
+#endif
+        const QString exec = QStandardPaths::findExecutable(drkonqi, libexecPaths());
         if (exec.isEmpty()) {
             qCDebug(LOG_KCRASH) << "Could not find drkonqi in search paths:" << libexecPaths();
             s_launchDrKonqi = 0;
@@ -546,12 +550,6 @@ void KCrash::defaultCrashHandler(int sig)
             }
         }
 
-        // make sure the constData() pointer remains valid when we call startProcess by making a copy
-        QByteArray startupId = KStartupInfo::startupId();
-        if (!startupId.isNull()) {
-            data.add("--startupid", startupId.constData());
-        }
-
         if (s_flags & SaferDialog) {
             data.addBool("--safer");
         }
